#!/usr/bin/env php
<?PHP

$ztprefs = getenv('ZENDTOPREFS');
if (@$ztprefs) {
  array_splice($argv, 1, 0, $ztprefs);
}

if ( count($argv) < 2 ) {
  printf("
  usage:
  
   %s <ZendTo preferences.php file>
  
   The ZendTo preferences.php file path should be canonical, not relative.
   Alternatively, do
     export ZENDTOPREFS=<full file path of preferences.php>
     %s

",$argv[0],$argv[0]);
  return 0;
}

if ( ! preg_match('/^\/.+/',$argv[1]) ) {
  echo "ERROR:  You must provide a canonical path to the preference file.\n";
  return 1;
}

include $argv[1];
include_once(NSSDROPBOX_LIB_DIR."Smartyconf.php");
include_once(NSSDROPBOX_LIB_DIR."NSSDropoff.php");

chdir(NSSDROPBOX_LIB_DIR); // So relative URLs work in email templates

if ( $theDropbox = new NSSDropbox($NSSDROPBOX_PREFS) ) {
  
  //
  // Get all drop-offs; they come back sorted according to their
  // creation date:
  //
  printf("\nNSSDropbox Cleanup of zendto for preference file:\n  %s\n\n",$argv[1]);
  printf("Gathering dropoffs with creation timestamps before: %s\n",
    timestampForTime( time() - $theDropbox->retainDays() * 24 * 60 * 60 ));
  $theDropbox->writeToLog(sprintf("Info: Cleanup expiring drop-offs from before %s", timestampForTime( time() - $theDropbox->retainDays() * 24 * 60 * 60 )));
  $oldDropoffs = NSSDropoff::dropoffsOutsideRetentionTime($theDropbox);
  if ( $oldDropoffs && ($iMax = count($oldDropoffs)) ) {
    $i = 0;
    while ( $i < $iMax ) {
      printf("- Removing [%s] %s <%s>\n",
        $oldDropoffs[$i]->claimID(),
        $oldDropoffs[$i]->senderName(),
        $oldDropoffs[$i]->senderEmail()
      );
      $theDropbox->writeToLog(sprintf("Info: Cleanup deleting expired drop-off %s from %s <%s>",
        $oldDropoffs[$i]->claimID(),
        $oldDropoffs[$i]->senderName(),
        $oldDropoffs[$i]->senderEmail()
      ));
      $oldDropoffs[$i]->removeDropoff();
      $i++;
    }
  } else {
    print "No dropoffs have expired.\n\n";
  }
  
  //
  // Now nag daily about dropoffs near to their retention limit,
  // that haven't been picked up by anyone.
  //
  if ($theDropbox->warningDays()>0) {
    printf("\nNSSDropbox Warn recipients about dropoffs close to expiry.\n");
    $oldDropoffs = NSSDropoff::dropoffsNearRetentionTime($theDropbox);
    if ( $oldDropoffs && ($iMax = count($oldDropoffs)) ) {
      $i = 0;
      while ( $i < $iMax ) {
        // Have there been any pickups of this dropoff?
        if ( $oldDropoffs[$i]->numPickups() < 1 ) {
          printf("- Reminding about [%s] %s <%s>\n",
            $oldDropoffs[$i]->claimID(),
            $oldDropoffs[$i]->senderName(),
            $oldDropoffs[$i]->senderEmail()
          );
          $theDropbox->writeToLog(sprintf("Info: Reminding %s <%s> to pick up drop-off %s near to expiry",
            $oldDropoffs[$i]->senderName(),
            $oldDropoffs[$i]->senderEmail(),
            $oldDropoffs[$i]->claimID()
          ));
          // We don't know for certain here whether the original email
          // to the recipient(s) included the passcode or not.
          // So we have to assume that if it is allowed at all, and the
          // default is to send the passcode, then we will send the
          // passcode here too.
          // It won't have been set by creating the NSSDropoff object
          // at all, as there's no corresponding database field for it
          // in the dropoff table.
          if ($theDropbox->allowEmailPasscode() &&
              $theDropbox->defaultEmailPasscode()) {
            $oldDropoffs[$i]->setresendWithPasscode(1);
          } else {
            $oldDropoffs[$i]->setresendWithPasscode(0);
          }
          // The 0 tells it not to reset the expiry timer.
          $oldDropoffs[$i]->resendDropoff(FALSE);
        }
        $i++;
      }
    } else {
      print "No dropoffs near expiry.\n\n";
    }
  }

  //
  // Do a orphan purge, too:
  //
  printf("Purging orphaned dropoffs:\n");
  NSSDropoff::cleanupOrphans($theDropbox);

  //
  // Now prune the auth table of old keys
  //
  printf("Purging old sender verification data:\n");
  $theDropbox->PruneAuthData();

  //
  // Now prune the req table of old keys
  //
  printf("Purging old request data:\n");
  $theDropbox->PruneReqData();
}

?>
